@@ -1,4 +1,5 @@
 """Command-line implementation of flake8."""
+import sys
 from typing import List, Optional
 
 from flake8.main import application
@@ -14,6 +15,9 @@ def main(argv=None):
     :param list argv:
         The arguments to be passed to the application for parsing.
     """
+    if argv is None:
+        argv = sys.argv[1:]
+
     app = application.Application()
     app.run(argv)
     app.exit()
