@@ -1,4 +1,5 @@
 """Test aggregation of config files and command-line options."""
+import argparse
 import os
 
 import pytest
@@ -14,9 +15,12 @@ CLI_SPECIFIED_CONFIG = 'tests/fixtures/config_files/cli-specified.ini'
 @pytest.fixture
 def optmanager():
     """Create a new OptionManager."""
+    prelim_parser = argparse.ArgumentParser(add_help=False)
+    options.register_preliminary_options(prelim_parser)
     option_manager = manager.OptionManager(
         prog='flake8',
         version='3.0.0',
+        parents=[prelim_parser],
     )
     options.register_default_options(option_manager)
     return option_manager
@@ -24,13 +28,14 @@ def optmanager():
 
 def test_aggregate_options_with_config(optmanager):
     """Verify we aggregate options and config values appropriately."""
-    arguments = ['flake8', '--config', CLI_SPECIFIED_CONFIG, '--select',
+    arguments = ['flake8', '--select',
                  'E11,E34,E402,W,F', '--exclude', 'tests/*']
-    config_finder = config.ConfigFileFinder('flake8', arguments, [])
+    config_finder = config.ConfigFileFinder(
+        'flake8',
+        config_file=CLI_SPECIFIED_CONFIG)
     options, args = aggregator.aggregate_options(
         optmanager, config_finder, arguments)
 
-    assert options.config == CLI_SPECIFIED_CONFIG
     assert options.select == ['E11', 'E34', 'E402', 'W', 'F']
     assert options.ignore == ['E123', 'W234', 'E111']
     assert options.exclude == [os.path.abspath('tests/*')]
@@ -38,14 +43,14 @@ def test_aggregate_options_with_config(optmanager):
 
 def test_aggregate_options_when_isolated(optmanager):
     """Verify we aggregate options and config values appropriately."""
-    arguments = ['flake8', '--isolated', '--select', 'E11,E34,E402,W,F',
+    arguments = ['flake8', '--select', 'E11,E34,E402,W,F',
                  '--exclude', 'tests/*']
-    config_finder = config.ConfigFileFinder('flake8', arguments, [])
+    config_finder = config.ConfigFileFinder(
+        'flake8', ignore_config_files=True)
     optmanager.extend_default_ignore(['E8'])
     options, args = aggregator.aggregate_options(
         optmanager, config_finder, arguments)
 
-    assert options.isolated is True
     assert options.select == ['E11', 'E34', 'E402', 'W', 'F']
     assert sorted(options.ignore) == [
         'E121', 'E123', 'E126', 'E226', 'E24', 'E704', 'E8', 'W503', 'W504',
