@@ -3,7 +3,9 @@ import mock
 import pytest
 
 from flake8 import checker
+from flake8._compat import importlib_metadata
 from flake8.plugins import manager
+from flake8.processor import FileProcessor
 
 PHYSICAL_LINE = "# Physical line content"
 
@@ -14,7 +16,7 @@ EXPECTED_RESULT_PHYSICAL_LINE = (
     0,
     1,
     'Expected Message',
-    PHYSICAL_LINE,
+    None,
 )
 
 
@@ -98,9 +100,14 @@ def mock_file_checker_with_plugin(plugin_target):
     entry_point = mock.Mock(spec=['load'])
     entry_point.name = plugin_target.name
     entry_point.load.return_value = plugin_target
+    entry_point.value = 'mocked:value'
 
     # Load the checker plugins using the entry point mock
-    with mock.patch('entrypoints.get_group_all', return_value=[entry_point]):
+    with mock.patch.object(
+            importlib_metadata,
+            'entry_points',
+            return_value={'flake8.extension': [entry_point]},
+    ):
         checks = manager.Checkers()
 
     # Prevent it from reading lines from stdin or somewhere else
@@ -148,11 +155,31 @@ def test_line_check_results(plugin_target, len_results):
     """Test the FileChecker class handling results from line checks."""
     file_checker = mock_file_checker_with_plugin(plugin_target)
 
-    # Results will be store in an internal array
+    # Results will be stored in an internal array
     file_checker.run_physical_checks(PHYSICAL_LINE)
-    assert file_checker.results == [
-        EXPECTED_RESULT_PHYSICAL_LINE
-    ] * len_results
+    expected = [EXPECTED_RESULT_PHYSICAL_LINE] * len_results
+    assert file_checker.results == expected
+
+
+def test_logical_line_offset_out_of_bounds():
+    """Ensure that logical line offsets that are out of bounds do not crash."""
+
+    @plugin_func
+    def _logical_line_out_of_bounds(logical_line):
+        yield 10000, 'L100 test'
+
+    file_checker = mock_file_checker_with_plugin(_logical_line_out_of_bounds)
+
+    logical_ret = (
+        '',
+        'print("xxxxxxxxxxx")',
+        [(0, (1, 0)), (5, (1, 5)), (6, (1, 6)), (19, (1, 19)), (20, (1, 20))],
+    )
+    with mock.patch.object(
+        FileProcessor, 'build_logical_line', return_value=logical_ret,
+    ):
+        file_checker.run_logical_checks()
+        assert file_checker.results == [('L100', 0, 0, 'test', None)]
 
 
 PLACEHOLDER_CODE = 'some_line = "of" * code'
@@ -206,13 +233,12 @@ def test_report_order(results, expected_order):
     file_checker.results = results
     file_checker.display_name = 'placeholder'
 
-    style_guide = mock.Mock(spec=['options'])
-    style_guide.processing_file = mock.MagicMock()
+    style_guide = mock.MagicMock(spec=['options', 'processing_file'])
 
     # Create a placeholder manager without arguments or plugins
     # Just add one custom file checker which just provides the results
     manager = checker.Manager(style_guide, [], [])
-    manager.checkers = [file_checker]
+    manager.checkers = manager._all_checkers = [file_checker]
 
     # _handle_results is the first place which gets the sorted result
     # Should something non-private be mocked instead?
@@ -220,3 +246,38 @@ def test_report_order(results, expected_order):
     with mock.patch.object(manager, '_handle_results', handler):
         assert manager.report() == (len(results), len(results))
         handler.assert_called_once_with('placeholder', expected_results)
+
+
+def test_acquire_when_multiprocessing_pool_can_initialize():
+    """Verify successful importing of hardware semaphore support.
+
+    Mock the behaviour of a platform that has a hardware sem_open
+    implementation, and then attempt to initialize a multiprocessing
+    Pool object.
+
+    This simulates the behaviour on most common platforms.
+    """
+    with mock.patch("multiprocessing.Pool") as pool:
+        result = checker._try_initialize_processpool(2)
+
+    pool.assert_called_once_with(2, checker._pool_init)
+    assert result is pool.return_value
+
+
+def test_acquire_when_multiprocessing_pool_can_not_initialize():
+    """Verify unsuccessful importing of hardware semaphore support.
+
+    Mock the behaviour of a platform that has not got a hardware sem_open
+    implementation, and then attempt to initialize a multiprocessing
+    Pool object.
+
+    This scenario will occur on platforms such as Termux and on some
+    more exotic devices.
+
+    https://github.com/python/cpython/blob/4e02981de0952f54bf87967f8e10d169d6946b40/Lib/multiprocessing/synchronize.py#L30-L33
+    """
+    with mock.patch("multiprocessing.Pool", side_effect=ImportError) as pool:
+        result = checker._try_initialize_processpool(2)
+
+    pool.assert_called_once_with(2, checker._pool_init)
+    assert result is None
