@@ -1,5 +1,5 @@
 """Tests for the BaseFormatter object."""
-import optparse
+import argparse
 
 import mock
 import pytest
@@ -9,10 +9,10 @@ from flake8.formatting import base
 
 
 def options(**kwargs):
-    """Create an optparse.Values instance."""
+    """Create an argparse.Namespace instance."""
     kwargs.setdefault('output_file', None)
     kwargs.setdefault('tee', False)
-    return optparse.Values(kwargs)
+    return argparse.Namespace(**kwargs)
 
 
 @pytest.mark.parametrize('filename', [None, 'out.txt'])
@@ -65,19 +65,29 @@ def test_show_source_returns_nothing_when_there_is_source():
     ) == ''
 
 
-@pytest.mark.parametrize('line, column', [
-    ('x=1\n', 2),
-    ('    x=(1\n       +2)\n', 5),
-    # TODO(sigmavirus24): Add more examples
+@pytest.mark.parametrize(('line1', 'line2', 'column'), [
+    (
+        'x=1\n',
+        ' ^',
+        2,
+    ),
+    (
+        '    x=(1\n       +2)\n',
+        '    ^',
+        5,
+    ),
+    (
+        '\tx\t=\ty\n',
+        '\t \t \t^',
+        6,
+    ),
 ])
-def test_show_source_updates_physical_line_appropriately(line, column):
+def test_show_source_updates_physical_line_appropriately(line1, line2, column):
     """Ensure the error column is appropriately indicated."""
     formatter = base.BaseFormatter(options(show_source=True))
-    error = style_guide.Violation('A000', 'file.py', 1, column, 'error', line)
+    error = style_guide.Violation('A000', 'file.py', 1, column, 'error', line1)
     output = formatter.show_source(error)
-    assert output
-    _, pointer = output.rsplit('\n', 1)
-    assert pointer.count(' ') == (column - 1)
+    assert output == line1 + line2
 
 
 @pytest.mark.parametrize('tee', [False, True])
@@ -137,7 +147,7 @@ class AfterInitFormatter(base.BaseFormatter):
 def test_after_init_is_always_called():
     """Verify after_init is called."""
     formatter = AfterInitFormatter(options())
-    assert getattr(formatter, 'post_initialized') is True
+    assert formatter.post_initialized is True
 
 
 class FormatFormatter(base.BaseFormatter):
