@@ -5,15 +5,15 @@ import mock
 import pytest
 
 from flake8 import checker
+from flake8.main.options import JobsArgument
 
 
-def style_guide_mock(**kwargs):
+def style_guide_mock():
     """Create a mock StyleGuide object."""
-    kwargs.setdefault('diff', False)
-    kwargs.setdefault('jobs', '4')
-    style_guide = mock.Mock()
-    style_guide.options = mock.Mock(**kwargs)
-    return style_guide
+    return mock.MagicMock(**{
+        'options.diff': False,
+        'options.jobs': JobsArgument("4"),
+    })
 
 
 def _parallel_checker_manager():
@@ -74,5 +74,7 @@ def test_make_checkers():
             with mock.patch('flake8.processor.FileProcessor'):
                 manager.make_checkers()
 
-    for file_checker in manager.checkers:
+    assert manager._all_checkers
+    for file_checker in manager._all_checkers:
         assert file_checker.filename in files
+    assert not manager.checkers  # the files don't exist
