@@ -13,8 +13,7 @@ def test_read_lines_splits_lines(default_options):
     file_processor = processor.FileProcessor(__file__, default_options)
     lines = file_processor.lines
     assert len(lines) > 5
-    assert any('"""Tests for the FileProcessor class."""' in line.rstrip()
-               for line in lines)
+    assert lines[0].strip() == '"""Tests for the FileProcessor class."""'
 
 
 def _lines_from_file(tmpdir, contents, options):
@@ -76,23 +75,28 @@ def test_should_ignore_file(lines, expected, default_options):
     assert file_processor.should_ignore_file() is expected
 
 
+def test_should_ignore_file_to_handle_disable_noqa(default_options):
+    """Verify that we ignore a file if told to."""
+    lines = ['# flake8: noqa']
+    file_processor = processor.FileProcessor('-', default_options, lines)
+    assert file_processor.should_ignore_file() is True
+    default_options.disable_noqa = True
+    file_processor = processor.FileProcessor('-', default_options, lines)
+    assert file_processor.should_ignore_file() is False
+
+
 @mock.patch('flake8.utils.stdin_get_value')
 def test_read_lines_from_stdin(stdin_get_value, default_options):
     """Verify that we use our own utility function to retrieve stdin."""
-    stdin_value = mock.Mock()
-    stdin_value.splitlines.return_value = []
-    stdin_get_value.return_value = stdin_value
+    stdin_get_value.return_value = ''
     processor.FileProcessor('-', default_options)
     stdin_get_value.assert_called_once_with()
-    stdin_value.splitlines.assert_called_once_with(True)
 
 
 @mock.patch('flake8.utils.stdin_get_value')
 def test_stdin_filename_attribute(stdin_get_value, default_options):
     """Verify that we update the filename attribute."""
-    stdin_value = mock.Mock()
-    stdin_value.splitlines.return_value = []
-    stdin_get_value.return_value = stdin_value
+    stdin_get_value.return_value = ''
     file_processor = processor.FileProcessor('-', default_options)
     assert file_processor.filename == 'stdin'
 
@@ -101,9 +105,7 @@ def test_stdin_filename_attribute(stdin_get_value, default_options):
 def test_read_lines_uses_display_name(stdin_get_value, default_options):
     """Verify that when processing stdin we use a display name if present."""
     default_options.stdin_display_name = 'display_name.py'
-    stdin_value = mock.Mock()
-    stdin_value.splitlines.return_value = []
-    stdin_get_value.return_value = stdin_value
+    stdin_get_value.return_value = ''
     file_processor = processor.FileProcessor('-', default_options)
     assert file_processor.filename == 'display_name.py'
 
@@ -113,24 +115,62 @@ def test_read_lines_ignores_empty_display_name(
         stdin_get_value, default_options,
 ):
     """Verify that when processing stdin we use a display name if present."""
-    stdin_value = mock.Mock()
-    stdin_value.splitlines.return_value = []
-    stdin_get_value.return_value = stdin_value
+    stdin_get_value.return_value = ''
     default_options.stdin_display_name = ''
     file_processor = processor.FileProcessor('-', default_options)
     assert file_processor.filename == 'stdin'
 
 
-def test_line_for(default_options):
+def test_noqa_line_for(default_options):
     """Verify we grab the correct line from the cached lines."""
     file_processor = processor.FileProcessor('-', default_options, lines=[
-        'Line 1',
-        'Line 2',
-        'Line 3',
+        'Line 1\n',
+        'Line 2\n',
+        'Line 3\n',
     ])
 
     for i in range(1, 4):
-        assert file_processor.line_for(i) == 'Line {0}'.format(i)
+        assert file_processor.noqa_line_for(i) == 'Line {0}\n'.format(i)
+
+
+def test_noqa_line_for_continuation(default_options):
+    """Verify that the correct "line" is retrieved for continuation."""
+    src = '''\
+from foo \\
+    import bar  # 2
+
+x = """
+hello
+world
+"""  # 7
+'''
+    lines = src.splitlines(True)
+    file_processor = processor.FileProcessor('-', default_options, lines=lines)
+
+    assert file_processor.noqa_line_for(0) is None
+
+    l_1_2 = 'from foo \\\n    import bar  # 2\n'
+    assert file_processor.noqa_line_for(1) == l_1_2
+    assert file_processor.noqa_line_for(2) == l_1_2
+
+    assert file_processor.noqa_line_for(3) == '\n'
+
+    l_4_7 = 'x = """\nhello\nworld\n"""  # 7\n'
+    for i in (4, 5, 6, 7):
+        assert file_processor.noqa_line_for(i) == l_4_7
+
+    assert file_processor.noqa_line_for(8) is None
+
+
+def test_noqa_line_for_no_eol_at_end_of_file(default_options):
+    """Verify that we properly handle noqa line at the end of the file."""
+    src = 'from foo \\\nimport bar'  # no end of file newline
+    lines = src.splitlines(True)
+    file_processor = processor.FileProcessor('-', default_options, lines=lines)
+
+    l_1_2 = 'from foo \\\nimport bar'
+    assert file_processor.noqa_line_for(1) == l_1_2
+    assert file_processor.noqa_line_for(2) == l_1_2
 
 
 def test_next_line(default_options):
@@ -146,24 +186,6 @@ def test_next_line(default_options):
         assert file_processor.line_number == i
 
 
-@pytest.mark.parametrize('error_code, line, expected_indent_char', [
-    ('E101', '\t\ta = 1', '\t'),
-    ('E101', '    a = 1', ' '),
-    ('W101', 'frobulate()', None),
-    ('F821', 'class FizBuz:', None),
-])
-def test_check_physical_error(
-        error_code, line, expected_indent_char, default_options,
-):
-    """Verify we update the indet char for the appropriate error code."""
-    file_processor = processor.FileProcessor('-', default_options, lines=[
-        'Line 1',
-    ])
-
-    file_processor.check_physical_error(error_code, line)
-    assert file_processor.indent_char == expected_indent_char
-
-
 @pytest.mark.parametrize('params, args, expected_kwargs', [
     ({'blank_before': True, 'blank_lines': True},
         None,
@@ -196,7 +218,7 @@ def test_keyword_arguments_for_does_not_handle_attribute_errors(
     ])
 
     with pytest.raises(AttributeError):
-        file_processor.keyword_arguments_for(['fake'])
+        file_processor.keyword_arguments_for({'fake': True})
 
 
 @pytest.mark.parametrize('unsplit_line, expected_lines', [
@@ -206,12 +228,13 @@ def test_keyword_arguments_for_does_not_handle_attribute_errors(
     ('line 1\n\nline 2\n', ['line 1', '', 'line 2']),
 ])
 def test_split_line(unsplit_line, expected_lines, default_options):
-    """Verify the token line spliting."""
+    """Verify the token line splitting."""
     file_processor = processor.FileProcessor('-', default_options, lines=[
         'Line 1',
     ])
 
-    actual_lines = list(file_processor.split_line((1, unsplit_line)))
+    token = (1, unsplit_line, (0, 0), (0, 0), '')
+    actual_lines = list(file_processor.split_line(token))
     assert expected_lines == actual_lines
 
     assert len(actual_lines) == file_processor.line_number
