@@ -1,26 +1,40 @@
 """Tests for Flake8's legacy API."""
+import argparse
+
 import mock
 import pytest
 
 from flake8.api import legacy as api
 from flake8.formatting import base as formatter
+from flake8.options.config import ConfigFileFinder
 
 
 def test_get_style_guide():
     """Verify the methods called on our internal Application."""
+    prelim_opts = argparse.Namespace(
+        append_config=[],
+        config=None,
+        isolated=False,
+        output_file=None,
+        verbose=0,
+    )
     mockedapp = mock.Mock()
-    mockedapp.prelim_opts.verbose = 0
-    mockedapp.prelim_opts.output_file = None
-    with mock.patch('flake8.main.application.Application') as application:
-        application.return_value = mockedapp
-        style_guide = api.get_style_guide()
+    mockedapp.parse_preliminary_options.return_value = (prelim_opts, [])
+    mockedapp.program = 'flake8'
+    with mock.patch('flake8.api.legacy.config.ConfigFileFinder') as mock_config_finder:  # noqa: E501
+        config_finder = ConfigFileFinder(mockedapp.program)
+        mock_config_finder.return_value = config_finder
+
+        with mock.patch('flake8.main.application.Application') as application:
+            application.return_value = mockedapp
+            style_guide = api.get_style_guide()
 
     application.assert_called_once_with()
-    mockedapp.parse_preliminary_options_and_args.assert_called_once_with([])
-    mockedapp.make_config_finder.assert_called_once_with()
-    mockedapp.find_plugins.assert_called_once_with()
+    mockedapp.parse_preliminary_options.assert_called_once_with([])
+    mockedapp.find_plugins.assert_called_once_with(config_finder)
     mockedapp.register_plugin_options.assert_called_once_with()
-    mockedapp.parse_configuration_and_cli.assert_called_once_with([])
+    mockedapp.parse_configuration_and_cli.assert_called_once_with(
+        config_finder, [])
     mockedapp.make_formatter.assert_called_once_with()
     mockedapp.make_guide.assert_called_once_with()
     mockedapp.make_file_checker_manager.assert_called_once_with()
@@ -28,7 +42,7 @@ def test_get_style_guide():
 
 
 def test_styleguide_options():
-    """Show tha we proxy the StyleGuide.options attribute."""
+    """Show that we proxy the StyleGuide.options attribute."""
     app = mock.Mock()
     app.options = 'options'
     style_guide = api.StyleGuide(app)
@@ -36,7 +50,7 @@ def test_styleguide_options():
 
 
 def test_styleguide_paths():
-    """Show tha we proxy the StyleGuide.paths attribute."""
+    """Show that we proxy the StyleGuide.paths attribute."""
     app = mock.Mock()
     app.paths = 'paths'
     style_guide = api.StyleGuide(app)
@@ -112,7 +126,7 @@ def test_styleguide_init_report():
 
     class FakeFormatter(formatter.BaseFormatter):
         def format(self, *args):
-            pass
+            raise NotImplementedError
 
     style_guide.init_report(FakeFormatter)
     app.make_formatter.assert_called_once_with(FakeFormatter)
