@@ -1,5 +1,5 @@
 """Tests for the flake8.style_guide.StyleGuide class."""
-import optparse
+import argparse
 
 import mock
 import pytest
@@ -11,7 +11,7 @@ from flake8.formatting import base
 
 
 def create_options(**kwargs):
-    """Create and return an instance of optparse.Values."""
+    """Create and return an instance of argparse.Namespace."""
     kwargs.setdefault('select', [])
     kwargs.setdefault('extended_default_select', [])
     kwargs.setdefault('ignore', [])
@@ -19,7 +19,7 @@ def create_options(**kwargs):
     kwargs.setdefault('disable_noqa', False)
     kwargs.setdefault('enable_extensions', [])
     kwargs.setdefault('per_file_ignores', [])
-    return optparse.Values(kwargs)
+    return argparse.Namespace(**kwargs)
 
 
 def test_handle_error_does_not_raise_type_errors():
@@ -78,10 +78,12 @@ def test_style_guide_manager_pre_file_ignores_parsing():
     options = create_options(per_file_ignores=PER_FILE_IGNORES_UNPARSED)
     guide = style_guide.StyleGuideManager(options, formatter=formatter)
     assert len(guide.style_guides) == 5
-    assert list(map(utils.normalize_path,
-                    ["first_file.py", "second_file.py", "third_file.py",
-                        "sub_dir/*"])
-                ) == [g.filename for g in guide.style_guides[1:]]
+    expected = [
+        utils.normalize_path(p) for p in [
+            "first_file.py", "second_file.py", "third_file.py", "sub_dir/*",
+        ]
+    ]
+    assert expected == [g.filename for g in guide.style_guides[1:]]
 
 
 @pytest.mark.parametrize('ignores,violation,filename,handle_error_return', [
